@@ -4,7 +4,7 @@ use Moose;
 use MooseX::StrictConstructor;
 use namespace::clean -except => 'meta';
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 extends qw(Hailo::Storage::Mixin::CHI);
 
@@ -22,7 +22,8 @@ __PACKAGE__->meta->make_immutable;
 
 =head1 NAME
 
-Hailo::Storage::CHI::BerkeleyDB - A L<BerkeleyDB|CHI::Driver::BerkeleyDB> storage backend for L<Hailo|Hailo> using L<CHI>
+Hailo::Storage::CHI::BerkeleyDB - A L<BerkeleyDB|CHI::Driver::BerkeleyDB>
+storage backend for L<Hailo|Hailo> using L<CHI>
 
 =head1 AUTHOR
 
@@ -36,4 +37,3 @@ This program is free software, you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
 =cut
-
